@@ -4,7 +4,7 @@ import numbers
 from six import integer_types
 from six import string_types
 
-from hackle.model import User, Event
+from hackle.model import Event
 
 
 def is_non_empty_string(input_id_key):
@@ -57,22 +57,6 @@ def is_finite_number(value):
     return True
 
 
-def is_valid_user(user):
-    if user is None:
-        return False
-
-    if user and not isinstance(user, User):
-        return False
-
-    if user and user.id is None:
-        return False
-
-    if user and not isinstance(user.id, string_types):
-        return False
-
-    return True
-
-
 def is_valid_event(event):
     if event is None:
         return False
