@@ -1,10 +1,13 @@
 import abc
 
+from six import add_metaclass
+
 from hackle.decision import DecisionReason
 from hackle.evaluation.evaluator import Evaluation
 
 
-class FlowEvaluator(object, metaclass=abc.ABCMeta):
+@add_metaclass(abc.ABCMeta)
+class FlowEvaluator(object):
 
     @abc.abstractmethod
     def evaluate(self, workspace, experiment, user, default_variation_key, next_flow):
@@ -111,8 +114,11 @@ class TargetRuleEvaluator(FlowEvaluator):
         if experiment.type != 'FEATURE_FLAG':
             raise Exception('experiment type must be FEATURE_FLAG [{}]'.format(experiment.id))
 
+        if user.identifiers.get(experiment.identifier_type) is None:
+            return next_flow.evaluate(workspace, experiment, user, default_variation_key)
+
         target_rule = self.target_rule_determiner.determine_target_rule_or_none(workspace, experiment, user)
-        if not target_rule:
+        if target_rule is None:
             return next_flow.evaluate(workspace, experiment, user, default_variation_key)
 
         variation = self.action_resolver.resolve_or_none(target_rule.action, workspace, experiment, user)
@@ -134,8 +140,45 @@ class DefaultRuleEvaluator(FlowEvaluator):
         if experiment.type != 'FEATURE_FLAG':
             raise Exception('experiment type must be FEATURE_FLAG [{}]'.format(experiment.id))
 
+        if user.identifiers.get(experiment.identifier_type) is None:
+            return Evaluation.of(experiment, default_variation_key, DecisionReason.DEFAULT_RULE)
+
         variation = self.action_resolver.resolve_or_none(experiment.default_rule, workspace, experiment, user)
         if not variation:
             raise Exception('FeatureFlag must decide the variation [{}]'.format(experiment.id))
 
         return Evaluation.with_variation(variation, DecisionReason.DEFAULT_RULE)
+
+
+class ContainerEvaluator(FlowEvaluator):
+
+    def __init__(self, container_resolver):
+        self.container_resolver = container_resolver
+
+    def evaluate(self, workspace, experiment, user, default_variation_key, next_flow):
+        container_id = experiment.container_id
+        if container_id is None:
+            return next_flow.evaluate(workspace, experiment, user, default_variation_key)
+
+        container = workspace.get_container_or_none(container_id)
+        if container is None:
+            raise Exception('Container[{}]'.format(container_id))
+
+        bucket = workspace.get_bucket_or_none(container.bucket_id)
+        if bucket is None:
+            raise Exception('Bucket[{}]'.format(container.bucket_id))
+
+        is_user_in_container_group = self.container_resolver.is_user_in_container_group(container, bucket, experiment,
+                                                                                        user)
+        if is_user_in_container_group:
+            return next_flow.evaluate(workspace, experiment, user, default_variation_key)
+        else:
+            return Evaluation.of(experiment, default_variation_key, DecisionReason.NOT_IN_MUTUAL_EXCLUSION_EXPERIMENT)
+
+
+class IdentifierEvaluator(FlowEvaluator):
+    def evaluate(self, workspace, experiment, user, default_variation_key, next_flow):
+        if user.identifiers.get(experiment.identifier_type) is not None:
+            return next_flow.evaluate(workspace, experiment, user, default_variation_key)
+        else:
+            return Evaluation.of(experiment, default_variation_key, DecisionReason.IDENTIFIER_NOT_FOUND)
