@@ -1,10 +1,14 @@
 import abc
 
+import six
+from six import add_metaclass
+
 from hackle import logger as _logging
 from hackle.evaluation.match.value_operator_matcher import ValueOperatorMatcher, ValueOperatorMatcherFactory
 
 
-class ConditionMatcher(object, metaclass=abc.ABCMeta):
+@add_metaclass(abc.ABCMeta)
+class ConditionMatcher(object):
 
     @abc.abstractmethod
     def matches(self, condition, workspace, user):
@@ -19,7 +23,7 @@ class UserConditionMatcher(ConditionMatcher):
 
     def matches(self, condition, workspace, user):
         user_value = self.user_value_resolver.resolve_or_none(user, condition.key)
-        if not user_value:
+        if user_value is None:
             return False
 
         return self.value_operator_matcher.matches(user_value, condition.match)
@@ -32,7 +36,7 @@ class UserValueResolver(object):
 
     def resolve_or_none(self, user, target_key):
         if target_key.type == 'USER_ID':
-            return user.id
+            return user.identifiers.get(target_key.name)
         elif target_key.type == 'USER_PROPERTY':
             return user.properties.get(target_key.name)
         elif target_key.type == 'HACKLE_PROPERTY':
@@ -62,7 +66,7 @@ class SegmentConditionMatcher(ConditionMatcher):
 
     def _matches(self, value, workspace, user):
         segment_key = value
-        if not isinstance(segment_key, str):
+        if not isinstance(segment_key, six.string_types):
             raise Exception('SegmentKey[{}]'.format(segment_key))
         segment = workspace.get_segment_or_none(segment_key)
         if not segment:
