@@ -1,10 +1,13 @@
 import abc
-from numbers import Number
 
+from six import add_metaclass, string_types
+
+from hackle.commons import validator
 from hackle.evaluation.match.semantic_version import SemanticVersion
 
 
-class OperatorMatcher(object, metaclass=abc.ABCMeta):
+@add_metaclass(abc.ABCMeta)
+class OperatorMatcher(object):
 
     @abc.abstractmethod
     def string_matches(self, user_value, match_value):
@@ -25,13 +28,13 @@ class OperatorMatcher(object, metaclass=abc.ABCMeta):
 
 class InMatcher(OperatorMatcher):
     def string_matches(self, user_value, match_value):
-        if isinstance(user_value, str) and isinstance(match_value, str):
+        if isinstance(user_value, string_types) and isinstance(match_value, string_types):
             return user_value == match_value
         else:
             return False
 
     def number_matches(self, user_value, match_value):
-        if isinstance(user_value, Number) and isinstance(match_value, Number):
+        if validator.is_finite_number(user_value) and validator.is_finite_number(match_value):
             return user_value == match_value
         else:
             return False
@@ -51,7 +54,7 @@ class InMatcher(OperatorMatcher):
 
 class ContainsMatcher(OperatorMatcher):
     def string_matches(self, user_value, match_value):
-        if isinstance(user_value, str) and isinstance(match_value, str):
+        if isinstance(user_value, string_types) and isinstance(match_value, string_types):
             return match_value in user_value
         else:
             return False
@@ -68,7 +71,7 @@ class ContainsMatcher(OperatorMatcher):
 
 class StartsWithMatcher(OperatorMatcher):
     def string_matches(self, user_value, match_value):
-        if isinstance(user_value, str) and isinstance(match_value, str):
+        if isinstance(user_value, string_types) and isinstance(match_value, string_types):
             return user_value.startswith(match_value)
         else:
             return False
@@ -85,7 +88,7 @@ class StartsWithMatcher(OperatorMatcher):
 
 class EndsWithMatcher(OperatorMatcher):
     def string_matches(self, user_value, match_value):
-        if isinstance(user_value, str) and isinstance(match_value, str):
+        if isinstance(user_value, string_types) and isinstance(match_value, string_types):
             return user_value.endswith(match_value)
         else:
             return False
@@ -105,7 +108,7 @@ class GreaterThanMatcher(OperatorMatcher):
         return False
 
     def number_matches(self, user_value, match_value):
-        if isinstance(user_value, Number) and isinstance(match_value, Number):
+        if validator.is_finite_number(user_value) and validator.is_finite_number(match_value):
             return user_value > match_value
         else:
             return False
@@ -125,7 +128,7 @@ class GreaterThanOrEqualToMatcher(OperatorMatcher):
         return False
 
     def number_matches(self, user_value, match_value):
-        if isinstance(user_value, Number) and isinstance(match_value, Number):
+        if validator.is_finite_number(user_value) and validator.is_finite_number(match_value):
             return user_value >= match_value
         else:
             return False
@@ -145,7 +148,7 @@ class LessThanMatcher(OperatorMatcher):
         return False
 
     def number_matches(self, user_value, match_value):
-        if isinstance(user_value, Number) and isinstance(match_value, Number):
+        if validator.is_finite_number(user_value) and validator.is_finite_number(match_value):
             return user_value < match_value
         else:
             return False
@@ -165,7 +168,7 @@ class LessThanOrEqualToMatcher(OperatorMatcher):
         return False
 
     def number_matches(self, user_value, match_value):
-        if isinstance(user_value, Number) and isinstance(match_value, Number):
+        if validator.is_finite_number(user_value) and validator.is_finite_number(match_value):
             return user_value <= match_value
         else:
             return False
