@@ -1,10 +1,13 @@
 import abc
-from numbers import Number
 
+from six import add_metaclass, string_types
+
+from hackle.commons import validator
 from hackle.evaluation.match.semantic_version import SemanticVersion
 
 
-class ValueMatcher(object, metaclass=abc.ABCMeta):
+@add_metaclass(abc.ABCMeta)
+class ValueMatcher(object):
 
     @abc.abstractmethod
     def matches(self, operator_matcher, user_value, match_value):
@@ -13,7 +16,7 @@ class ValueMatcher(object, metaclass=abc.ABCMeta):
 
 class StringValueMatcher(ValueMatcher):
     def matches(self, operator_matcher, user_value, match_value):
-        if isinstance(user_value, str) and isinstance(match_value, str):
+        if isinstance(user_value, string_types) and isinstance(match_value, string_types):
             return operator_matcher.string_matches(user_value, match_value)
         else:
             return False
@@ -21,7 +24,7 @@ class StringValueMatcher(ValueMatcher):
 
 class NumberValueMatcher(ValueMatcher):
     def matches(self, operator_matcher, user_value, match_value):
-        if isinstance(user_value, Number) and isinstance(match_value, Number):
+        if validator.is_finite_number(user_value) and validator.is_finite_number(match_value):
             return operator_matcher.number_matches(user_value, match_value)
         else:
             return False
