@@ -55,20 +55,28 @@ class BatchEventProcessor(object):
     def _run(self):
         try:
             while True:
-                if self._get_time() >= self.flushing_interval_deadline:
+                base_time = self._get_time()
+                base_time_flush_interval = self._get_time(self.flush_interval.total_seconds())
+                if base_time >= self.flushing_interval_deadline:
                     self._flush_batch()
-                    self.flushing_interval_deadline = self._get_time() + \
-                                                      self._get_time(self.flush_interval.total_seconds())
+                    self.flushing_interval_deadline = base_time + base_time_flush_interval
                     self.logger.debug('Flush interval deadline. Flushed batch.')
 
                 try:
-                    interval = self.flushing_interval_deadline - self._get_time()
+                    interval = self.flushing_interval_deadline - base_time
+                    self.logger.debug('flush interval')
                     item = self.event_queue.get(True, interval)
 
+                    self.logger.debug('item type is {}'.format(type(item).__name__))
                     if item is None:
                         continue
 
                 except queue.Empty:
+                    self.logger.debug('Queue is empty.')
+                    continue
+
+                except Exception as e:
+                    self.logger.debug('queue processing exception.', e)
                     continue
 
                 if item == self._SHUTDOWN_SIGNAL:
@@ -94,6 +102,8 @@ class BatchEventProcessor(object):
         self.event_queue.put(self._FLUSH_SIGNAL)
 
     def _flush_batch(self):
+        self.logger.debug('Called _flush_batch {}'.format(self._current_batch))
+
         batch_len = len(self._current_batch)
         if batch_len == 0:
             self.logger.debug('Noting to flush')
@@ -125,16 +135,24 @@ class BatchEventProcessor(object):
             self.logger.error('Error dispatching event : {} {}'.format(str(events), str(exception)))
 
     def process(self, event):
+        if not isinstance(event, UserEvent):
+            self.logger.error('Event is in an invalid format. Received event of type {}.'.format(type(event).__name__))
+            return
+
+        self.logger.debug('Received event of type {}.'.format(type(event).__name__))
+
         try:
             self.event_queue.put_nowait(event)
         except queue.Full:
             self.logger.debug('Queue is full. Current size : {}'.format(str(self.event_queue.qsize())))
 
     def _add_to_batch(self, event):
+        self.logger.debug('Called add to batch')
         if len(self._current_batch) == 0:
             self.flushing_interval_deadline = self._get_time() + self._get_time(self.flush_interval.total_seconds())
 
         with self.LOCK:
+            self.logger.debug('Called add to batch append')
             self._current_batch.append(event)
         if len(self._current_batch) >= self.batch_size:
             self.logger.debug('Flushing batch size {}'.format(str(self.batch_size)))
