@@ -1,6 +1,6 @@
 import json
 
-from hackle.entities import *
+from .entities import *
 
 
 class Workspace(object):
@@ -12,6 +12,7 @@ class Workspace(object):
         self.feature_flag_key_map = self._experiment_key_map('FEATURE_FLAG', json_data.get('featureFlags', []))
         self.event_type_key_map = self._event_type_key_map(json_data.get('events', []))
         self.segment_key_map = self._segment_key_map(json_data.get('segments', []))
+        self._container_id_map = self._container_id_map(json_data.get('containers', []))
 
     def get_experiment_or_none(self, experiment_key):
         return self.experiment_key_map.get(experiment_key)
@@ -28,6 +29,9 @@ class Workspace(object):
     def get_segment_or_none(self, segment_key):
         return self.segment_key_map.get(segment_key)
 
+    def get_container_or_none(self, container_id):
+        return self._container_id_map.get(container_id)
+
     @staticmethod
     def _bucket_id_map(buckets_data):
         bucket_id_map = {}
@@ -84,6 +88,7 @@ class Workspace(object):
             id=experiment_data['id'],
             key=experiment_data['key'],
             type=type,
+            identifier_type=experiment_data['identifierType'],
             status=status,
             version=experiment_data['version'],
             variations=variations,
@@ -93,6 +98,7 @@ class Workspace(object):
             target_audiences=Workspace._targets(execution_data.get('targetAudiences', []), TargetingTypes.PROPERTY),
             target_rules=Workspace._target_rules(execution_data.get('targetRules', []), TargetingTypes.PROPERTY),
             default_rule=Workspace._target_action(execution_data['defaultRule']),
+            container_id=experiment_data.get('containerId'),
             winner_variation_id=experiment_data.get('winnerVariationId')
         )
 
@@ -219,3 +225,30 @@ class Workspace(object):
             type=segment_data['type'],
             targets=Workspace._targets(segment_data['targets'], TargetingTypes.SEGMENT)
         )
+
+    @staticmethod
+    def _container_id_map(containers_data):
+        _container_id_map = {}
+        for container_data in containers_data:
+            container = Workspace._container(container_data)
+            _container_id_map[container.id] = container
+        return _container_id_map
+
+    @staticmethod
+    def _container(container_data):
+        groups = []
+        for container_group_data in container_data.get('groups', []):
+            container_group = Workspace._container_group(container_group_data)
+            groups.append(container_group)
+        return Container(
+            id=container_data['id'],
+            bucket_id=container_data['bucketId'],
+            groups=groups
+        )
+
+    @staticmethod
+    def _container_group(container_group_data):
+        return ContainerGroup(
+            id=container_group_data['id'],
+            experiments=container_group_data['experiments']
+        )
